import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:project_telephony/utils/headers.dart';
import 'package:project_telephony/utils/hive_store.dart';

import '../../base/base_style.dart';
import '../../model/hive/phone_model.dart';
import '../exclude/exclude_contacts_page.dart';
import '../exclude/exclude_single_page.dart';

import '../widget/plone_back_button.dart';

class CallListPage extends StatefulWidget {
  final String title;
  final List<PhoneNum> phoneNum;
final int index;
  const CallListPage({Key? key, required this.title, required this.phoneNum,required this.index})
      : super(key: key);

  @override
  _CallListPageState createState() => _CallListPageState();
}

class _CallListPageState extends State<CallListPage> {
  final EasyRefreshController _refreshController = EasyRefreshController();
  List<PhoneModel> messList = [];
  List<PhoneNum> numList = [];

  @override
  void dispose() {
    _refreshController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      appBar: AppBar(
          centerTitle: true,
          elevation: 0,
          title: Text(
            widget.title,
            style: TextStyle(
                fontSize: BaseStyle.fontSize34,
                color: BaseStyle.color333333,
                fontWeight: FontWeight.bold),
          ),
          // titleSpacing: 150.w,
          leading: const CloudBackButton(
            isSpecial: true,
            isSpecials: false,
          ),
          backgroundColor: kForeGroundColor),
      backgroundColor: Colors.white,
      body: EasyRefresh(
          firstRefresh: true,
          controller: _refreshController,
          header: MaterialHeader(),
          // footer: MaterialFooter(),
          onRefresh: () async {
            // await userProvider.updateUserInfo();

            setState(() {});
          },
          child: widget.phoneNum.isEmpty
              ? _getNullList()
              : _getNum(widget.phoneNum)

          // ListView(
          //   children: [findList.isEmpty ? _getNullList() : _getNum()],
          // )

          ),
      bottomNavigationBar: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          62.wb,
          _getBottom("号码添加", const Color(0xFF1890FF), () {
            Navigator.of(context)
                .push(
                  MaterialPageRoute(builder: (_) =>  ExcludeSinglePage( qf: true,index: widget.index,)),
                )
                .then((value) => _refreshController.callRefresh());
          }, Colors.white, Colors.white, 2, const Color(0xFF1890FF), 58, 24),
          32.wb,
          _getBottom("通讯录中添加", Colors.white, () {
            Navigator.of(context)
                .push(
                  MaterialPageRoute(
                      builder: (_) =>  ExcludeContactsPage(
                            qf: true,
                            index: widget.index,
                          )),
                )
                .then((val) => _refreshController.callRefresh());
          }, const Color(0xFF74BCFF), const Color(0xFF1890FF), 0, Colors.white,
              96, 24),
          62.wb,
        ],
      ),
    );
  }

  _getBottom(String text, Color textColor, VoidCallback ontap, Color color1,
      Color color2, int border, Color borderColor, int h, int v) {
    return GestureDetector(
      onTap: ontap,
      child: Container(
        padding: EdgeInsets.symmetric(horizontal: h.w, vertical: v.w),
        margin: EdgeInsets.only(bottom: 32.w),
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(8.w),
            gradient: LinearGradient(
                colors: [color1, color2],
                end: Alignment.centerRight,
                begin: Alignment.centerLeft),
            border: Border.all(width: border.w, color: borderColor)),
        child: Text(
          text,
          style: TextStyle(
              fontSize: 28.sp, color: textColor, fontWeight: FontWeight.w500),
        ),
      ),
    );
  }

  _getNullList() {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      // crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        490.hb,
        Image.asset(
          Assets.icons.nullphonelist.path,
          width: 240.w,
          height: 212.w,
          fit: BoxFit.fill,
        ),
        48.hb,
        Text(
          "这里是空的",
          style: TextStyle(
              color: const Color(0xFF999999),
              fontWeight: FontWeight.bold,
              fontSize: 36.sp),
        ),
        16.hb,
        Text(
          "还没有添加指定号码",
          style: TextStyle(color: const Color(0xFF999999), fontSize: 28.sp),
        ),
        490.hb,
      ],
    );
  }

  _getNum(List<PhoneNum> item) {
    return ListView.builder(
      itemBuilder: (context, index) {
        return Container(
          margin: EdgeInsets.symmetric(horizontal: 16.w),
          child: ListTile(
            onTap: () async {},
            title: Text(
              item[index].name ?? "",
              style: TextStyle(fontSize: 32.w, fontWeight: FontWeight.bold),
            ),
            subtitle: Text(
              item[index].phone ?? "",
              style: TextStyle(fontSize: 28.sp, color: BaseStyle.color999999),
            ),
            trailing: TextButton(
              style: ButtonStyle(
                  side: MaterialStateProperty.all(
                      BorderSide(width: 2.w, color: const Color(0xFFE8E8E8)))),
              onPressed: () async {
                // print("123");
                messList =
                    await HiveStore.dataBox?.get("ml").cast<PhoneModel>();
                // numList = HiveStore.dataBox?.get("pl").cast<PhoneNum>();
                // print(item[index]);
                // messList.removeWhere((element) => (element.phoneList)!.contains(item[index]));
                // numList.remove(item[index]);
                  messList[widget.index].phoneList!.remove(item[index]);
                HiveStore.dataBox?.put("ml", messList);
                print(HiveStore.dataBox?.get("ml"));
                _refreshController.callRefresh();
                // print(HiveStore.dataBox?.get("pl"));
              },
              child: Text(
                "删除",
                style: TextStyle(fontSize: 28.sp, color: BaseStyle.color333333),
              ),
            ),
          ),
        );

        //   CheckboxListTile(
        //   onChanged: (bool? value) {
        //     setState(() {
        //       item[index].state = value!;
        //       if (item[index].state!) {
        //         // phoneNum3.add({"phone":num,"remark":name});
        //         // phoneNum3.add((phone: num, remark: name));
        //       } else {
        //         // phoneNum3.remove({"phone":num,"remark":name});
        //         // phoneNum3.remove(ExcludePnModel(phone: num, remark: name)) ;
        //       }
        //     });
        //   },
        //   value: item[index].state,
        //   title: Text(
        //     item[index].name ?? "",
        //     style: TextStyle(fontSize: 32.w, fontWeight: FontWeight.bold),
        //   ),
        //   subtitle: Row(
        //     children: [
        //       Text(
        //         item[index].phone ?? "",
        //         style: TextStyle(fontSize: 28.sp, color: BaseStyle.color999999),
        //       ),
        //       // 30.wb,
        //       // Text(
        //       //   item.name == null ? "" : item.name!,
        //       //   style: TextStyle(fontSize: 28.sp, color: BaseStyle.color999999),
        //       // )
        //     ],
        //   ),
        // );
      },
      itemCount: widget.phoneNum.length,
    );
  }
}
